@@ -16,7 +16,11 @@ from PyFin.Math.Accumulators.IAccumulators import Acosh
 from PyFin.Math.Accumulators.IAccumulators import Asin
 from PyFin.Math.Accumulators.IAccumulators import Asinh
 from PyFin.Math.Accumulators.IAccumulators import NormInv
+from PyFin.Math.Accumulators.IAccumulators import Current
 from PyFin.Math.Accumulators.IAccumulators import Latest
+from PyFin.Math.Accumulators.IAccumulators import Ceil
+from PyFin.Math.Accumulators.IAccumulators import Floor
+from PyFin.Math.Accumulators.IAccumulators import Round
 from PyFin.Math.Accumulators.IAccumulators import Identity
 from PyFin.Math.Accumulators.IAccumulators import IIF
 from PyFin.Math.Accumulators.IAccumulators import Sign
@@ -38,7 +42,9 @@ from PyFin.Math.Accumulators.StatelessAccumulators import Variance
 from PyFin.Math.Accumulators.StatelessAccumulators import Product
 
 from PyFin.Math.Accumulators.StatefulAccumulators import Shift
+from PyFin.Math.Accumulators.StatefulAccumulators import Delta
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverage
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingDecay
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveAverage
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeAverage
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingPositiveDifferenceAverage
@@ -52,7 +58,9 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingStandardDeviation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingArgMax
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMin
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingArgMin
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingRank
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingQuantile
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAllTrue
@@ -80,6 +88,7 @@ __all__ = ["Exp",
            "Asin",
            "Asinh",
            "NormInv",
+           "Current",
            "Latest",
            "Sign",
            "Diff",
@@ -97,9 +106,11 @@ __all__ = ["Exp",
            "MACD",
            "Variance",
            "Shift",
+           "Delta",
            "IIF",
            "Identity",
            "MovingAverage",
+           "MovingDecay",
            "MovingPositiveAverage",
            "MovingNegativeAverage",
            "MovingPositiveDifferenceAverage",
@@ -111,7 +122,9 @@ __all__ = ["Exp",
            "MovingNegativeVariance",
            "MovingCorrelation",
            "MovingMax",
+           "MovingArgMax",
            "MovingMin",
+           "MovingArgMin",
            "MovingRank",
            "MovingQuantile",
            "MovingAllTrue",
